@@ -33,7 +33,7 @@ class Requests:
         return await self._get_location(roadeids, area, RequestPath.road)
 
     async def get_zone_point(self, zoneeids: list = None, area: BaseGeometry = None) -> dict:
-        return await self._get_location(zoneeids, area, RequestPath.zone)
+        return await self._get_location(zoneeids, area, RequestPath.zonepoint)
 
     async def _get_location(self, eids: list, area: BaseGeometry, applyto: str, params: dict = None) -> dict:
         if params is None:
@@ -129,6 +129,9 @@ class Requests:
         return await self._get(SEPARATOR.join((RequestPath.zonepoint, RequestPath.traveltime)), params)
 
     async def _get(self, suffix: str, params: dict = None) -> dict:
+        if params is None:
+            params = {}
+        params[RequestParam.internalflag] = ''
         message = {}
         async with self.session as session:
             url = '{}{}'.format(SEPARATOR.join((self.apiurl, suffix)), SEPARATOR)
